@@ -3,7 +3,7 @@
 ##
 ## Scott Wiersdorf
 ## Created: Fri May  9 14:03:01 MDT 2003
-## Updated: $Id: Crontab.pm,v 1.6 2011/04/11 22:39:19 scott Exp $
+## Updated: $Id: Crontab.pm,v 1.7 2011/04/11 22:55:03 scott Exp $
 ##
 ## Config::Crontab - a crontab(5) parser
 ##
@@ -39,7 +39,7 @@ our @ISA = qw(Config::Crontab::Base Config::Crontab::Container);
 use Fcntl;
 use File::Temp qw(:POSIX);
 
-our $VERSION = '1.32';
+our $VERSION = '1.33';
 
 sub init {
     my $self = shift;
@@ -101,7 +101,12 @@ sub read {
     else {
 	my $crontab_cmd = "crontab -l 2>/dev/null|";
 	if( $self->owner ) {
-	    $crontab_cmd = "crontab -u " . $self->owner . " -l 2>/dev/null|";
+            if( $^O eq 'SunOS' ) {
+                $crontab_cmd = "crontab -l " . $self->owner . " 2>/dev/null|";
+            }
+            else {
+                $crontab_cmd = "crontab -u " . $self->owner . " -l 2>/dev/null|";
+            }
 	}
 	open FILE, $crontab_cmd
 	  or do {
